@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2002, Industrial Light & Magic, a division of Lucas
+// Copyright (c) 2002-2012, Industrial Light & Magic, a division of Lucas
 // Digital Ltd. LLC
 // 
 // All rights reserved.
@@ -33,8 +33,6 @@
 ///////////////////////////////////////////////////////////////////////////
 
 
-#include <tmpDir.h>
-
 #include <ImfOutputFile.h>
 #include <ImfInputFile.h>
 #include <ImfChannelList.h>
@@ -44,9 +42,11 @@
 #include <stdio.h>
 #include <assert.h>
 
+
+using namespace OPENEXR_IMF_NAMESPACE;
 using namespace std;
-using namespace Imath;
-using namespace Imf;
+using namespace IMATH_NAMESPACE;
+
 
 namespace {
 
@@ -180,16 +180,16 @@ writeCopyRead (const Array2D<half> &ph1,
 
 
 void
-writeCopyRead (const Array2D<half> &ph, int w, int h, int dx, int dy)
+writeCopyRead (const std::string &tempDir, const Array2D<half> &ph, int w, int h, int dx, int dy)
 {
-    const char *filename1 = IMF_TMP_DIR "imf_test_copy1.exr";
-    const char *filename2 = IMF_TMP_DIR "imf_test_copy2.exr";
+    std::string filename1 = tempDir + "imf_test_copy1.exr";
+    std::string filename2 = tempDir + "imf_test_copy2.exr";
 
     for (int comp = 0; comp < NUM_COMPRESSION_METHODS; ++comp)
     {
 	writeCopyRead (ph,
-		       filename1,
-		       filename2,
+		       filename1.c_str(),
+		       filename2.c_str(),
 		       w, h,
 		       dx, dy,
 		       Compression (comp));
@@ -200,7 +200,7 @@ writeCopyRead (const Array2D<half> &ph, int w, int h, int dx, int dy)
 
 
 void
-testCopyPixels ()
+testCopyPixels (const std::string &tempDir)
 {
     try
     {
@@ -214,10 +214,10 @@ testCopyPixels ()
 	Array2D<half> ph (H, W);
 
 	fillPixels (ph, W, H);
-	writeCopyRead (ph, W, H, 0,  0);
-	writeCopyRead (ph, W, H, 0,  DY);
-	writeCopyRead (ph, W, H, DX, 0);
-	writeCopyRead (ph, W, H, DX, DY);
+	writeCopyRead (tempDir, ph, W, H, 0,  0);
+	writeCopyRead (tempDir, ph, W, H, 0,  DY);
+	writeCopyRead (tempDir, ph, W, H, DX, 0);
+	writeCopyRead (tempDir, ph, W, H, DX, DY);
 
 	cout << "ok\n" << endl;
     }
